# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from billingo.api_client import ApiClient


class DocumentApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive_document(self, id, **kwargs):  # noqa: E501
        """Archive a proforma document.  # noqa: E501

        Archive an existing proforma document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_document(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.archive_document_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.archive_document_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def archive_document_with_http_info(self, id, **kwargs):  # noqa: E501
        """Archive a proforma document.  # noqa: E501

        Archive an existing proforma document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_document_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `archive_document`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}/archive', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cancel_document(self, id, **kwargs):  # noqa: E501
        """Cancel a document  # noqa: E501

        Cancel a document. Returns a cancellation document object if the cancellation is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_document(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :param DocumentCancellation body: Comment and notifiable email addresses - comma separated for multiple email addresses
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cancel_document_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.cancel_document_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def cancel_document_with_http_info(self, id, **kwargs):  # noqa: E501
        """Cancel a document  # noqa: E501

        Cancel a document. Returns a cancellation document object if the cancellation is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_document_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :param DocumentCancellation body: Comment and notifiable email addresses - comma separated for multiple email addresses
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `cancel_document`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}/cancel', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Document',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_document(self, body, **kwargs):  # noqa: E501
        """Create a document  # noqa: E501

        Create a new document. Returns a document object if the create is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_document(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DocumentInsert body: DocumentInsert object that you would like to store. (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_document_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_document_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_document_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create a document  # noqa: E501

        Create a new document. Returns a document object if the create is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_document_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DocumentInsert body: DocumentInsert object that you would like to store. (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_document`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Document',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_document_from_draft(self, body, id, **kwargs):  # noqa: E501
        """Converts a draft to an invoice.  # noqa: E501

        Converts a draft to an invoice. Returns the invoice object if the convert is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_document_from_draft(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DocumentInsert body: DocumentInsert object that you would like to store. (required)
        :param int id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_document_from_draft_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_document_from_draft_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def create_document_from_draft_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Converts a draft to an invoice.  # noqa: E501

        Converts a draft to an invoice. Returns the invoice object if the convert is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_document_from_draft_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DocumentInsert body: DocumentInsert object that you would like to store. (required)
        :param int id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_document_from_draft" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_document_from_draft`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `create_document_from_draft`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Document',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_document_from_proforma(self, id, **kwargs):  # noqa: E501
        """Create a document from proforma.  # noqa: E501

        Create a new document from proforma. Returns a document object if the create is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_document_from_proforma(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :param InvoiceSettings body: InvoiceSettings object.
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_document_from_proforma_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_document_from_proforma_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def create_document_from_proforma_with_http_info(self, id, **kwargs):  # noqa: E501
        """Create a document from proforma.  # noqa: E501

        Create a new document from proforma. Returns a document object if the create is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_document_from_proforma_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :param InvoiceSettings body: InvoiceSettings object.
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_document_from_proforma" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `create_document_from_proforma`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}/create-from-proforma', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Document',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_modification_document(self, body, id, **kwargs):  # noqa: E501
        """Create a modification document.  # noqa: E501

        Create a modification document for the given document. Returns a new document object if the create is successful.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_modification_document(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ModificationDocumentInsert body: ModificationDocumentInsert object that you would like to store. (required)
        :param int id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_modification_document_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_modification_document_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def create_modification_document_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Create a modification document.  # noqa: E501

        Create a modification document for the given document. Returns a new document object if the create is successful.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_modification_document_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ModificationDocumentInsert body: ModificationDocumentInsert object that you would like to store. (required)
        :param int id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_modification_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_modification_document`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `create_modification_document`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}/create-modification-document', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Document',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_receipt(self, body, **kwargs):  # noqa: E501
        """Create a receipt  # noqa: E501

        Create a new receipt. Returns a document object if the create is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_receipt(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReceiptInsert body: ReceiptInsert object that you would like to store. (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_receipt_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_receipt_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_receipt_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create a receipt  # noqa: E501

        Create a new receipt. Returns a document object if the create is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_receipt_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReceiptInsert body: ReceiptInsert object that you would like to store. (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_receipt" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_receipt`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/receipt', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Document',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_receipt_from_draft(self, body, id, **kwargs):  # noqa: E501
        """Converts a draft to a receipt.  # noqa: E501

        Converts a draft to a receipt. Returns the receipt object if the convert is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_receipt_from_draft(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReceiptInsert body: ReceiptInsert object that you would like to store. (required)
        :param int id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_receipt_from_draft_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_receipt_from_draft_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def create_receipt_from_draft_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Converts a draft to a receipt.  # noqa: E501

        Converts a draft to a receipt. Returns the receipt object if the convert is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_receipt_from_draft_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReceiptInsert body: ReceiptInsert object that you would like to store. (required)
        :param int id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_receipt_from_draft" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_receipt_from_draft`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `create_receipt_from_draft`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/receipt/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Document',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_document(self, id, **kwargs):  # noqa: E501
        """Delete a draft.  # noqa: E501

        Delete an existing draft.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_document(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_document_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_document_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_document_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete a draft.  # noqa: E501

        Delete an existing draft.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_document_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_document`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_payment(self, id, **kwargs):  # noqa: E501
        """Delete all payment history on document  # noqa: E501

        Delete all exist payment history on document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_payment(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: list[PaymentHistory]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_payment_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_payment_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_payment_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete all payment history on document  # noqa: E501

        Delete all exist payment history on document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_payment_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: list[PaymentHistory]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_payment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_payment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}/payments', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PaymentHistory]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def document_copy(self, id, **kwargs):  # noqa: E501
        """Copy a document  # noqa: E501

        Copy a document. Returns the new document if the copy was succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.document_copy(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.document_copy_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.document_copy_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def document_copy_with_http_info(self, id, **kwargs):  # noqa: E501
        """Copy a document  # noqa: E501

        Copy a document. Returns the new document if the copy was succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.document_copy_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method document_copy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `document_copy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}/copy', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Document',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def download_document(self, id, **kwargs):  # noqa: E501
        """Download a document in PDF format.  # noqa: E501

        Download a document. Returns a document in PDF format.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_document(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_document_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.download_document_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def download_document_with_http_info(self, id, **kwargs):  # noqa: E501
        """Download a document in PDF format.  # noqa: E501

        Download a document. Returns a document in PDF format.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_document_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `download_document`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/pdf', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}/download', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_document(self, id, **kwargs):  # noqa: E501
        """Retrieve a document  # noqa: E501

        Retrieves the details of an existing document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_document(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_document_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_document_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_document_with_http_info(self, id, **kwargs):  # noqa: E501
        """Retrieve a document  # noqa: E501

        Retrieves the details of an existing document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_document_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_document`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Document',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_document_by_vendor_id(self, vendor_id, **kwargs):  # noqa: E501
        """Retrieve a document by vendor id  # noqa: E501

        Retrieves the details of an existing document by vendor id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_document_by_vendor_id(vendor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vendor_id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_document_by_vendor_id_with_http_info(vendor_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_document_by_vendor_id_with_http_info(vendor_id, **kwargs)  # noqa: E501
            return data

    def get_document_by_vendor_id_with_http_info(self, vendor_id, **kwargs):  # noqa: E501
        """Retrieve a document by vendor id  # noqa: E501

        Retrieves the details of an existing document by vendor id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_document_by_vendor_id_with_http_info(vendor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vendor_id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vendor_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_document_by_vendor_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vendor_id' is set
        if ('vendor_id' not in params or
                params['vendor_id'] is None):
            raise ValueError("Missing the required parameter `vendor_id` when calling `get_document_by_vendor_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'vendor_id' in params:
            path_params['vendor_id'] = params['vendor_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/vendor/{vendor_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Document',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_online_szamla_status(self, id, **kwargs):  # noqa: E501
        """Retrieve a document Online Számla status  # noqa: E501

        Retrieves the details of an existing document status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_online_szamla_status(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: OnlineSzamlaStatus
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_online_szamla_status_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_online_szamla_status_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_online_szamla_status_with_http_info(self, id, **kwargs):  # noqa: E501
        """Retrieve a document Online Számla status  # noqa: E501

        Retrieves the details of an existing document status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_online_szamla_status_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: OnlineSzamlaStatus
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_online_szamla_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_online_szamla_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}/online-szamla', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OnlineSzamlaStatus',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_payment(self, id, **kwargs):  # noqa: E501
        """Retrieve a payment histroy  # noqa: E501

        Retrieves the details of payment history an existing document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_payment(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: list[PaymentHistory]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_payment_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_payment_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_payment_with_http_info(self, id, **kwargs):  # noqa: E501
        """Retrieve a payment histroy  # noqa: E501

        Retrieves the details of payment history an existing document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_payment_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: list[PaymentHistory]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_payment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_payment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}/payments', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PaymentHistory]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_public_url(self, id, **kwargs):  # noqa: E501
        """Retrieve a document download public url.  # noqa: E501

        Retrieves public url to download an existing document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_public_url(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: DocumentPublicUrl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_public_url_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_public_url_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_public_url_with_http_info(self, id, **kwargs):  # noqa: E501
        """Retrieve a document download public url.  # noqa: E501

        Retrieves public url to download an existing document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_public_url_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: DocumentPublicUrl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_public_url" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_public_url`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}/public-url', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DocumentPublicUrl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_document(self, **kwargs):  # noqa: E501
        """List all documents  # noqa: E501

        Returns a list of your documents. The documents are returned sorted by creation date, with the most recent documents appearing first.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_document(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page:
        :param int per_page:
        :param int block_id: Filter documents by the identifier of your DocumentBlock.
        :param int partner_id: Filter documents by the identifier of your Partner.
        :param PaymentMethod payment_method: Filter documents by PaymentMethod value.
        :param PaymentStatus payment_status: Filter documents by PaymentStatus value.
        :param date start_date: Filter documents by their invoice date.
        :param date end_date: Filter documents by their invoice date.
        :param int start_number: Starting number of the document, should not contain year or any other formatting. Required if `start_year` given
        :param int end_number: Ending number of the document, should not contain year or any other formatting. Required if `end_year` given
        :param int start_year: Year for `start_number` parameter. Required if `start_number` given.
        :param int end_year: Year for `end_number` parameter. Required if `end_number` given.
        :param DocumentType type: Filter documents by type
        :param str query: Filter documents by the given text
        :param date paid_start_date: Filter documents by their payment date.
        :param date paid_end_date: Filter documents by their payment date.
        :param date fulfillment_start_date: Filter documents by their fulfillment date.
        :param date fulfillment_end_date: Filter documents by their fulfillment date.
        :param str last_modified_date: Filter documents by their last modified date.
        :return: DocumentList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_document_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_document_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_document_with_http_info(self, **kwargs):  # noqa: E501
        """List all documents  # noqa: E501

        Returns a list of your documents. The documents are returned sorted by creation date, with the most recent documents appearing first.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_document_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page:
        :param int per_page:
        :param int block_id: Filter documents by the identifier of your DocumentBlock.
        :param int partner_id: Filter documents by the identifier of your Partner.
        :param PaymentMethod payment_method: Filter documents by PaymentMethod value.
        :param PaymentStatus payment_status: Filter documents by PaymentStatus value.
        :param date start_date: Filter documents by their invoice date.
        :param date end_date: Filter documents by their invoice date.
        :param int start_number: Starting number of the document, should not contain year or any other formatting. Required if `start_year` given
        :param int end_number: Ending number of the document, should not contain year or any other formatting. Required if `end_year` given
        :param int start_year: Year for `start_number` parameter. Required if `start_number` given.
        :param int end_year: Year for `end_number` parameter. Required if `end_number` given.
        :param DocumentType type: Filter documents by type
        :param str query: Filter documents by the given text
        :param date paid_start_date: Filter documents by their payment date.
        :param date paid_end_date: Filter documents by their payment date.
        :param date fulfillment_start_date: Filter documents by their fulfillment date.
        :param date fulfillment_end_date: Filter documents by their fulfillment date.
        :param str last_modified_date: Filter documents by their last modified date.
        :return: DocumentList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page', 'per_page', 'block_id', 'partner_id', 'payment_method', 'payment_status', 'start_date', 'end_date', 'start_number', 'end_number', 'start_year', 'end_year', 'type', 'query', 'paid_start_date', 'paid_end_date', 'fulfillment_start_date', 'fulfillment_end_date', 'last_modified_date']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_document" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501
        if 'block_id' in params:
            query_params.append(('block_id', params['block_id']))  # noqa: E501
        if 'partner_id' in params:
            query_params.append(('partner_id', params['partner_id']))  # noqa: E501
        if 'payment_method' in params:
            query_params.append(('payment_method', params['payment_method']))  # noqa: E501
        if 'payment_status' in params:
            query_params.append(('payment_status', params['payment_status']))  # noqa: E501
        if 'start_date' in params:
            query_params.append(('start_date', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('end_date', params['end_date']))  # noqa: E501
        if 'start_number' in params:
            query_params.append(('start_number', params['start_number']))  # noqa: E501
        if 'end_number' in params:
            query_params.append(('end_number', params['end_number']))  # noqa: E501
        if 'start_year' in params:
            query_params.append(('start_year', params['start_year']))  # noqa: E501
        if 'end_year' in params:
            query_params.append(('end_year', params['end_year']))  # noqa: E501
        if 'type' in params:
            query_params.append(('type', params['type']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501
        if 'paid_start_date' in params:
            query_params.append(('paid_start_date', params['paid_start_date']))  # noqa: E501
        if 'paid_end_date' in params:
            query_params.append(('paid_end_date', params['paid_end_date']))  # noqa: E501
        if 'fulfillment_start_date' in params:
            query_params.append(('fulfillment_start_date', params['fulfillment_start_date']))  # noqa: E501
        if 'fulfillment_end_date' in params:
            query_params.append(('fulfillment_end_date', params['fulfillment_end_date']))  # noqa: E501
        if 'last_modified_date' in params:
            query_params.append(('last_modified_date', params['last_modified_date']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DocumentList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def pos_print(self, id, size, **kwargs):  # noqa: E501
        """Returns a printable POS PDF  # noqa: E501

        Returns a printable POS PDF file of a particular document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pos_print(id, size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :param float size: In which size the POS PDF should be rendered. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.pos_print_with_http_info(id, size, **kwargs)  # noqa: E501
        else:
            (data) = self.pos_print_with_http_info(id, size, **kwargs)  # noqa: E501
            return data

    def pos_print_with_http_info(self, id, size, **kwargs):  # noqa: E501
        """Returns a printable POS PDF  # noqa: E501

        Returns a printable POS PDF file of a particular document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pos_print_with_http_info(id, size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :param float size: In which size the POS PDF should be rendered. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method pos_print" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `pos_print`")  # noqa: E501
        # verify the required parameter 'size' is set
        if ('size' not in params or
                params['size'] is None):
            raise ValueError("Missing the required parameter `size` when calling `pos_print`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'size' in params:
            query_params.append(('size', params['size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/pdf', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}/print/pos', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_document(self, id, **kwargs):  # noqa: E501
        """Send invoice to given email adresses.  # noqa: E501

        Returns a list of emails, where the invoice is sent.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_document(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :param SendDocument body: List of email-s where you want to send the invoice.
        :return: SendDocument
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_document_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.send_document_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def send_document_with_http_info(self, id, **kwargs):  # noqa: E501
        """Send invoice to given email adresses.  # noqa: E501

        Returns a list of emails, where the invoice is sent.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_document_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :param SendDocument body: List of email-s where you want to send the invoice.
        :return: SendDocument
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `send_document`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}/send', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SendDocument',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_payment(self, body, id, **kwargs):  # noqa: E501
        """Update payment history  # noqa: E501

        Update payment history an existing document. Returns a payment history object if the update is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_payment(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[PaymentHistory] body: Payment history object that you would like to update. (required)
        :param int id: (required)
        :return: list[PaymentHistory]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_payment_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_payment_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def update_payment_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Update payment history  # noqa: E501

        Update payment history an existing document. Returns a payment history object if the update is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_payment_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[PaymentHistory] body: Payment history object that you would like to update. (required)
        :param int id: (required)
        :return: list[PaymentHistory]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_payment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_payment`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_payment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/documents/{id}/payments', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PaymentHistory]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SpendingSave(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'currency': 'Currency',
        'conversion_rate': 'float',
        'total_gross': 'float',
        'total_gross_huf': 'float',
        'total_vat_amount': 'float',
        'total_vat_amount_huf': 'float',
        'fulfillment_date': 'date',
        'paid_at': 'date',
        'category': 'Category',
        'comment': 'str',
        'invoice_number': 'str',
        'invoice_date': 'date',
        'due_date': 'date',
        'payment_method': 'SpendingPaymentMethod',
        'partner_id': 'int'
    }

    attribute_map = {
        'currency': 'currency',
        'conversion_rate': 'conversion_rate',
        'total_gross': 'total_gross',
        'total_gross_huf': 'total_gross_huf',
        'total_vat_amount': 'total_vat_amount',
        'total_vat_amount_huf': 'total_vat_amount_huf',
        'fulfillment_date': 'fulfillment_date',
        'paid_at': 'paid_at',
        'category': 'category',
        'comment': 'comment',
        'invoice_number': 'invoice_number',
        'invoice_date': 'invoice_date',
        'due_date': 'due_date',
        'payment_method': 'payment_method',
        'partner_id': 'partner_id'
    }

    def __init__(self, currency=None, conversion_rate=None, total_gross=None, total_gross_huf=None, total_vat_amount=None, total_vat_amount_huf=None, fulfillment_date=None, paid_at=None, category=None, comment=None, invoice_number=None, invoice_date=None, due_date=None, payment_method=None, partner_id=None):  # noqa: E501
        """SpendingSave - a model defined in Swagger"""  # noqa: E501
        self._currency = None
        self._conversion_rate = None
        self._total_gross = None
        self._total_gross_huf = None
        self._total_vat_amount = None
        self._total_vat_amount_huf = None
        self._fulfillment_date = None
        self._paid_at = None
        self._category = None
        self._comment = None
        self._invoice_number = None
        self._invoice_date = None
        self._due_date = None
        self._payment_method = None
        self._partner_id = None
        self.discriminator = None
        self.currency = currency
        if conversion_rate is not None:
            self.conversion_rate = conversion_rate
        self.total_gross = total_gross
        self.total_gross_huf = total_gross_huf
        self.total_vat_amount = total_vat_amount
        self.total_vat_amount_huf = total_vat_amount_huf
        self.fulfillment_date = fulfillment_date
        if paid_at is not None:
            self.paid_at = paid_at
        self.category = category
        if comment is not None:
            self.comment = comment
        if invoice_number is not None:
            self.invoice_number = invoice_number
        if invoice_date is not None:
            self.invoice_date = invoice_date
        if due_date is not None:
            self.due_date = due_date
        self.payment_method = payment_method
        if partner_id is not None:
            self.partner_id = partner_id

    @property
    def currency(self):
        """Gets the currency of this SpendingSave.  # noqa: E501


        :return: The currency of this SpendingSave.  # noqa: E501
        :rtype: Currency
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this SpendingSave.


        :param currency: The currency of this SpendingSave.  # noqa: E501
        :type: Currency
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501

        self._currency = currency

    @property
    def conversion_rate(self):
        """Gets the conversion_rate of this SpendingSave.  # noqa: E501


        :return: The conversion_rate of this SpendingSave.  # noqa: E501
        :rtype: float
        """
        return self._conversion_rate

    @conversion_rate.setter
    def conversion_rate(self, conversion_rate):
        """Sets the conversion_rate of this SpendingSave.


        :param conversion_rate: The conversion_rate of this SpendingSave.  # noqa: E501
        :type: float
        """

        self._conversion_rate = conversion_rate

    @property
    def total_gross(self):
        """Gets the total_gross of this SpendingSave.  # noqa: E501


        :return: The total_gross of this SpendingSave.  # noqa: E501
        :rtype: float
        """
        return self._total_gross

    @total_gross.setter
    def total_gross(self, total_gross):
        """Sets the total_gross of this SpendingSave.


        :param total_gross: The total_gross of this SpendingSave.  # noqa: E501
        :type: float
        """
        if total_gross is None:
            raise ValueError("Invalid value for `total_gross`, must not be `None`")  # noqa: E501

        self._total_gross = total_gross

    @property
    def total_gross_huf(self):
        """Gets the total_gross_huf of this SpendingSave.  # noqa: E501


        :return: The total_gross_huf of this SpendingSave.  # noqa: E501
        :rtype: float
        """
        return self._total_gross_huf

    @total_gross_huf.setter
    def total_gross_huf(self, total_gross_huf):
        """Sets the total_gross_huf of this SpendingSave.


        :param total_gross_huf: The total_gross_huf of this SpendingSave.  # noqa: E501
        :type: float
        """
        if total_gross_huf is None:
            raise ValueError("Invalid value for `total_gross_huf`, must not be `None`")  # noqa: E501

        self._total_gross_huf = total_gross_huf

    @property
    def total_vat_amount(self):
        """Gets the total_vat_amount of this SpendingSave.  # noqa: E501


        :return: The total_vat_amount of this SpendingSave.  # noqa: E501
        :rtype: float
        """
        return self._total_vat_amount

    @total_vat_amount.setter
    def total_vat_amount(self, total_vat_amount):
        """Sets the total_vat_amount of this SpendingSave.


        :param total_vat_amount: The total_vat_amount of this SpendingSave.  # noqa: E501
        :type: float
        """
        if total_vat_amount is None:
            raise ValueError("Invalid value for `total_vat_amount`, must not be `None`")  # noqa: E501

        self._total_vat_amount = total_vat_amount

    @property
    def total_vat_amount_huf(self):
        """Gets the total_vat_amount_huf of this SpendingSave.  # noqa: E501


        :return: The total_vat_amount_huf of this SpendingSave.  # noqa: E501
        :rtype: float
        """
        return self._total_vat_amount_huf

    @total_vat_amount_huf.setter
    def total_vat_amount_huf(self, total_vat_amount_huf):
        """Sets the total_vat_amount_huf of this SpendingSave.


        :param total_vat_amount_huf: The total_vat_amount_huf of this SpendingSave.  # noqa: E501
        :type: float
        """
        if total_vat_amount_huf is None:
            raise ValueError("Invalid value for `total_vat_amount_huf`, must not be `None`")  # noqa: E501

        self._total_vat_amount_huf = total_vat_amount_huf

    @property
    def fulfillment_date(self):
        """Gets the fulfillment_date of this SpendingSave.  # noqa: E501


        :return: The fulfillment_date of this SpendingSave.  # noqa: E501
        :rtype: date
        """
        return self._fulfillment_date

    @fulfillment_date.setter
    def fulfillment_date(self, fulfillment_date):
        """Sets the fulfillment_date of this SpendingSave.


        :param fulfillment_date: The fulfillment_date of this SpendingSave.  # noqa: E501
        :type: date
        """
        if fulfillment_date is None:
            raise ValueError("Invalid value for `fulfillment_date`, must not be `None`")  # noqa: E501

        self._fulfillment_date = fulfillment_date

    @property
    def paid_at(self):
        """Gets the paid_at of this SpendingSave.  # noqa: E501


        :return: The paid_at of this SpendingSave.  # noqa: E501
        :rtype: date
        """
        return self._paid_at

    @paid_at.setter
    def paid_at(self, paid_at):
        """Sets the paid_at of this SpendingSave.


        :param paid_at: The paid_at of this SpendingSave.  # noqa: E501
        :type: date
        """

        self._paid_at = paid_at

    @property
    def category(self):
        """Gets the category of this SpendingSave.  # noqa: E501


        :return: The category of this SpendingSave.  # noqa: E501
        :rtype: Category
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this SpendingSave.


        :param category: The category of this SpendingSave.  # noqa: E501
        :type: Category
        """
        if category is None:
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    @property
    def comment(self):
        """Gets the comment of this SpendingSave.  # noqa: E501


        :return: The comment of this SpendingSave.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this SpendingSave.


        :param comment: The comment of this SpendingSave.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def invoice_number(self):
        """Gets the invoice_number of this SpendingSave.  # noqa: E501


        :return: The invoice_number of this SpendingSave.  # noqa: E501
        :rtype: str
        """
        return self._invoice_number

    @invoice_number.setter
    def invoice_number(self, invoice_number):
        """Sets the invoice_number of this SpendingSave.


        :param invoice_number: The invoice_number of this SpendingSave.  # noqa: E501
        :type: str
        """

        self._invoice_number = invoice_number

    @property
    def invoice_date(self):
        """Gets the invoice_date of this SpendingSave.  # noqa: E501


        :return: The invoice_date of this SpendingSave.  # noqa: E501
        :rtype: date
        """
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, invoice_date):
        """Sets the invoice_date of this SpendingSave.


        :param invoice_date: The invoice_date of this SpendingSave.  # noqa: E501
        :type: date
        """

        self._invoice_date = invoice_date

    @property
    def due_date(self):
        """Gets the due_date of this SpendingSave.  # noqa: E501


        :return: The due_date of this SpendingSave.  # noqa: E501
        :rtype: date
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this SpendingSave.


        :param due_date: The due_date of this SpendingSave.  # noqa: E501
        :type: date
        """

        self._due_date = due_date

    @property
    def payment_method(self):
        """Gets the payment_method of this SpendingSave.  # noqa: E501


        :return: The payment_method of this SpendingSave.  # noqa: E501
        :rtype: SpendingPaymentMethod
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this SpendingSave.


        :param payment_method: The payment_method of this SpendingSave.  # noqa: E501
        :type: SpendingPaymentMethod
        """
        if payment_method is None:
            raise ValueError("Invalid value for `payment_method`, must not be `None`")  # noqa: E501

        self._payment_method = payment_method

    @property
    def partner_id(self):
        """Gets the partner_id of this SpendingSave.  # noqa: E501


        :return: The partner_id of this SpendingSave.  # noqa: E501
        :rtype: int
        """
        return self._partner_id

    @partner_id.setter
    def partner_id(self, partner_id):
        """Sets the partner_id of this SpendingSave.


        :param partner_id: The partner_id of this SpendingSave.  # noqa: E501
        :type: int
        """

        self._partner_id = partner_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SpendingSave, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpendingSave):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SpendingList(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data': 'list[SpendingListItem]',
        'total': 'int',
        'per_page': 'int',
        'current_page': 'int',
        'last_page': 'int',
        'prev_page_url': 'str',
        'next_page_url': 'str'
    }

    attribute_map = {
        'data': 'data',
        'total': 'total',
        'per_page': 'per_page',
        'current_page': 'current_page',
        'last_page': 'last_page',
        'prev_page_url': 'prev_page_url',
        'next_page_url': 'next_page_url'
    }

    def __init__(self, data=None, total=None, per_page=None, current_page=None, last_page=None, prev_page_url=None, next_page_url=None):  # noqa: E501
        """SpendingList - a model defined in Swagger"""  # noqa: E501
        self._data = None
        self._total = None
        self._per_page = None
        self._current_page = None
        self._last_page = None
        self._prev_page_url = None
        self._next_page_url = None
        self.discriminator = None
        if data is not None:
            self.data = data
        if total is not None:
            self.total = total
        if per_page is not None:
            self.per_page = per_page
        if current_page is not None:
            self.current_page = current_page
        if last_page is not None:
            self.last_page = last_page
        if prev_page_url is not None:
            self.prev_page_url = prev_page_url
        if next_page_url is not None:
            self.next_page_url = next_page_url

    @property
    def data(self):
        """Gets the data of this SpendingList.  # noqa: E501


        :return: The data of this SpendingList.  # noqa: E501
        :rtype: list[SpendingListItem]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this SpendingList.


        :param data: The data of this SpendingList.  # noqa: E501
        :type: list[SpendingListItem]
        """

        self._data = data

    @property
    def total(self):
        """Gets the total of this SpendingList.  # noqa: E501


        :return: The total of this SpendingList.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this SpendingList.


        :param total: The total of this SpendingList.  # noqa: E501
        :type: int
        """

        self._total = total

    @property
    def per_page(self):
        """Gets the per_page of this SpendingList.  # noqa: E501


        :return: The per_page of this SpendingList.  # noqa: E501
        :rtype: int
        """
        return self._per_page

    @per_page.setter
    def per_page(self, per_page):
        """Sets the per_page of this SpendingList.


        :param per_page: The per_page of this SpendingList.  # noqa: E501
        :type: int
        """

        self._per_page = per_page

    @property
    def current_page(self):
        """Gets the current_page of this SpendingList.  # noqa: E501


        :return: The current_page of this SpendingList.  # noqa: E501
        :rtype: int
        """
        return self._current_page

    @current_page.setter
    def current_page(self, current_page):
        """Sets the current_page of this SpendingList.


        :param current_page: The current_page of this SpendingList.  # noqa: E501
        :type: int
        """

        self._current_page = current_page

    @property
    def last_page(self):
        """Gets the last_page of this SpendingList.  # noqa: E501


        :return: The last_page of this SpendingList.  # noqa: E501
        :rtype: int
        """
        return self._last_page

    @last_page.setter
    def last_page(self, last_page):
        """Sets the last_page of this SpendingList.


        :param last_page: The last_page of this SpendingList.  # noqa: E501
        :type: int
        """

        self._last_page = last_page

    @property
    def prev_page_url(self):
        """Gets the prev_page_url of this SpendingList.  # noqa: E501


        :return: The prev_page_url of this SpendingList.  # noqa: E501
        :rtype: str
        """
        return self._prev_page_url

    @prev_page_url.setter
    def prev_page_url(self, prev_page_url):
        """Sets the prev_page_url of this SpendingList.


        :param prev_page_url: The prev_page_url of this SpendingList.  # noqa: E501
        :type: str
        """

        self._prev_page_url = prev_page_url

    @property
    def next_page_url(self):
        """Gets the next_page_url of this SpendingList.  # noqa: E501


        :return: The next_page_url of this SpendingList.  # noqa: E501
        :rtype: str
        """
        return self._next_page_url

    @next_page_url.setter
    def next_page_url(self, next_page_url):
        """Sets the next_page_url of this SpendingList.


        :param next_page_url: The next_page_url of this SpendingList.  # noqa: E501
        :type: str
        """

        self._next_page_url = next_page_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SpendingList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpendingList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PaymentMethod(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    ARUHITEL = "aruhitel"
    BANKCARD = "bankcard"
    BARION = "barion"
    BARTER = "barter"
    CASH = "cash"
    CASH_ON_DELIVERY = "cash_on_delivery"
    COUPON = "coupon"
    ELORE_UTALAS = "elore_utalas"
    EP_KARTYA = "ep_kartya"
    KOMPENZACIO = "kompenzacio"
    LEVONAS = "levonas"
    ONLINE_BANKCARD = "online_bankcard"
    OTHER = "other"
    PAYLIKE = "paylike"
    PAYONEER = "payoneer"
    PAYPAL = "paypal"
    PAYPAL_UTOLAG = "paypal_utolag"
    PAYU = "payu"
    PICK_PACK_PONT = "pick_pack_pont"
    POSTAI_CSEKK = "postai_csekk"
    POSTAUTALVANY = "postautalvany"
    SKRILL = "skrill"
    SZEP_CARD = "szep_card"
    TRANSFERWISE = "transferwise"
    UPWORK = "upwork"
    UTALVANY = "utalvany"
    VALTO = "valto"
    WIRE_TRANSFER = "wire_transfer"
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """PaymentMethod - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentMethod, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentMethod):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from billingo.models.address import Address
from billingo.models.bank_account import BankAccount
from billingo.models.bank_account_list import BankAccountList
from billingo.models.category import Category
from billingo.models.check_tax_number_message import CheckTaxNumberMessage
from billingo.models.client_error import ClientError
from billingo.models.client_error_response import ClientErrorResponse
from billingo.models.conversation_rate import ConversationRate
from billingo.models.correction_type import CorrectionType
from billingo.models.country import Country
from billingo.models.create_document_export import CreateDocumentExport
from billingo.models.currency import Currency
from billingo.models.date_type import DateType
from billingo.models.discount import Discount
from billingo.models.discount_type import DiscountType
from billingo.models.document import Document
from billingo.models.document_ancestor import DocumentAncestor
from billingo.models.document_bank_account import DocumentBankAccount
from billingo.models.document_block import DocumentBlock
from billingo.models.document_block_list import DocumentBlockList
from billingo.models.document_block_type import DocumentBlockType
from billingo.models.document_cancellation import DocumentCancellation
from billingo.models.document_export_filter_extra import DocumentExportFilterExtra
from billingo.models.document_export_id import DocumentExportId
from billingo.models.document_export_other_options import DocumentExportOtherOptions
from billingo.models.document_export_query_type import DocumentExportQueryType
from billingo.models.document_export_sort_by import DocumentExportSortBy
from billingo.models.document_export_status import DocumentExportStatus
from billingo.models.document_export_status_state import DocumentExportStatusState
from billingo.models.document_export_type import DocumentExportType
from billingo.models.document_form import DocumentForm
from billingo.models.document_format import DocumentFormat
from billingo.models.document_insert import DocumentInsert
from billingo.models.document_insert_type import DocumentInsertType
from billingo.models.document_item import DocumentItem
from billingo.models.document_item_data import DocumentItemData
from billingo.models.document_language import DocumentLanguage
from billingo.models.document_list import DocumentList
from billingo.models.document_notification_status import DocumentNotificationStatus
from billingo.models.document_organization import DocumentOrganization
from billingo.models.document_partner import DocumentPartner
from billingo.models.document_product_data import DocumentProductData
from billingo.models.document_public_url import DocumentPublicUrl
from billingo.models.document_settings import DocumentSettings
from billingo.models.document_summary import DocumentSummary
from billingo.models.document_type import DocumentType
from billingo.models.document_vat_rate_summary import DocumentVatRateSummary
from billingo.models.entitlement import Entitlement
from billingo.models.feature import Feature
from billingo.models.id import Id
from billingo.models.invoice_settings import InvoiceSettings
from billingo.models.ledger_number_information import LedgerNumberInformation
from billingo.models.modification_document_insert import ModificationDocumentInsert
from billingo.models.one_of_document_insert_items_items import OneOfDocumentInsertItemsItems
from billingo.models.one_of_modification_document_insert_items_items import OneOfModificationDocumentInsertItemsItems
from billingo.models.one_of_receipt_insert_items_items import OneOfReceiptInsertItemsItems
from billingo.models.online_payment import OnlinePayment
from billingo.models.online_szamla_status import OnlineSzamlaStatus
from billingo.models.online_szamla_status_enum import OnlineSzamlaStatusEnum
from billingo.models.online_szamla_status_message import OnlineSzamlaStatusMessage
from billingo.models.organization_data import OrganizationData
from billingo.models.partner import Partner
from billingo.models.partner_custom_billing_settings import PartnerCustomBillingSettings
from billingo.models.partner_list import PartnerList
from billingo.models.partner_tax_type import PartnerTaxType
from billingo.models.payment_history import PaymentHistory
from billingo.models.payment_method import PaymentMethod
from billingo.models.payment_status import PaymentStatus
from billingo.models.payment_status_spending import PaymentStatusSpending
from billingo.models.product import Product
from billingo.models.product_list import ProductList
from billingo.models.receipt_insert import ReceiptInsert
from billingo.models.receipt_item_data import ReceiptItemData
from billingo.models.receipt_product_data import ReceiptProductData
from billingo.models.round import Round
from billingo.models.send_document import SendDocument
from billingo.models.server_error import ServerError
from billingo.models.server_error_response import ServerErrorResponse
from billingo.models.server_time import ServerTime
from billingo.models.source import Source
from billingo.models.spending import Spending
from billingo.models.spending_list import SpendingList
from billingo.models.spending_list_item import SpendingListItem
from billingo.models.spending_partner import SpendingPartner
from billingo.models.spending_payment_method import SpendingPaymentMethod
from billingo.models.spending_save import SpendingSave
from billingo.models.subscription import Subscription
from billingo.models.subscription_error_response import SubscriptionErrorResponse
from billingo.models.tax_number import TaxNumber
from billingo.models.too_many_requests_response import TooManyRequestsResponse
from billingo.models.unit_price_type import UnitPriceType
from billingo.models.validation_error import ValidationError
from billingo.models.validation_error_response import ValidationErrorResponse
from billingo.models.vat import Vat



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ModificationDocumentInsert(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'due_date': 'date',
        'comment': 'str',
        'payment_method': 'PaymentMethod',
        'without_financial_fulfillment': 'bool',
        'items': 'list[OneOfModificationDocumentInsertItemsItems]'
    }

    attribute_map = {
        'due_date': 'due_date',
        'comment': 'comment',
        'payment_method': 'payment_method',
        'without_financial_fulfillment': 'without_financial_fulfillment',
        'items': 'items'
    }

    def __init__(self, due_date=None, comment=None, payment_method=None, without_financial_fulfillment=False, items=None):  # noqa: E501
        """ModificationDocumentInsert - a model defined in Swagger"""  # noqa: E501
        self._due_date = None
        self._comment = None
        self._payment_method = None
        self._without_financial_fulfillment = None
        self._items = None
        self.discriminator = None
        if due_date is not None:
            self.due_date = due_date
        if comment is not None:
            self.comment = comment
        if payment_method is not None:
            self.payment_method = payment_method
        if without_financial_fulfillment is not None:
            self.without_financial_fulfillment = without_financial_fulfillment
        if items is not None:
            self.items = items

    @property
    def due_date(self):
        """Gets the due_date of this ModificationDocumentInsert.  # noqa: E501


        :return: The due_date of this ModificationDocumentInsert.  # noqa: E501
        :rtype: date
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this ModificationDocumentInsert.


        :param due_date: The due_date of this ModificationDocumentInsert.  # noqa: E501
        :type: date
        """

        self._due_date = due_date

    @property
    def comment(self):
        """Gets the comment of this ModificationDocumentInsert.  # noqa: E501


        :return: The comment of this ModificationDocumentInsert.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this ModificationDocumentInsert.


        :param comment: The comment of this ModificationDocumentInsert.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def payment_method(self):
        """Gets the payment_method of this ModificationDocumentInsert.  # noqa: E501


        :return: The payment_method of this ModificationDocumentInsert.  # noqa: E501
        :rtype: PaymentMethod
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this ModificationDocumentInsert.


        :param payment_method: The payment_method of this ModificationDocumentInsert.  # noqa: E501
        :type: PaymentMethod
        """

        self._payment_method = payment_method

    @property
    def without_financial_fulfillment(self):
        """Gets the without_financial_fulfillment of this ModificationDocumentInsert.  # noqa: E501


        :return: The without_financial_fulfillment of this ModificationDocumentInsert.  # noqa: E501
        :rtype: bool
        """
        return self._without_financial_fulfillment

    @without_financial_fulfillment.setter
    def without_financial_fulfillment(self, without_financial_fulfillment):
        """Sets the without_financial_fulfillment of this ModificationDocumentInsert.


        :param without_financial_fulfillment: The without_financial_fulfillment of this ModificationDocumentInsert.  # noqa: E501
        :type: bool
        """

        self._without_financial_fulfillment = without_financial_fulfillment

    @property
    def items(self):
        """Gets the items of this ModificationDocumentInsert.  # noqa: E501


        :return: The items of this ModificationDocumentInsert.  # noqa: E501
        :rtype: list[OneOfModificationDocumentInsertItemsItems]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this ModificationDocumentInsert.


        :param items: The items of this ModificationDocumentInsert.  # noqa: E501
        :type: list[OneOfModificationDocumentInsertItemsItems]
        """

        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModificationDocumentInsert, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModificationDocumentInsert):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import billingo
from billingo.api.spending_api import SpendingApi  # noqa: E501
from billingo.rest import ApiException


class TestSpendingApi(unittest.TestCase):
    """SpendingApi unit test stubs"""

    def setUp(self):
        self.api = SpendingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_spending_delete(self):
        """Test case for spending_delete

        Deletes a spending.  # noqa: E501
        """
        pass

    def test_spending_list(self):
        """Test case for spending_list

        Lists all spending  # noqa: E501
        """
        pass

    def test_spending_save(self):
        """Test case for spending_save

        Creates a new spending.  # noqa: E501
        """
        pass

    def test_spending_show(self):
        """Test case for spending_show

        Retrieves one specific spending.  # noqa: E501
        """
        pass

    def test_spending_update(self):
        """Test case for spending_update

        Updates a spending item.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DocumentSettings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'mediated_service': 'bool',
        'without_financial_fulfillment': 'bool',
        'online_payment': 'OnlinePayment',
        'round': 'Round',
        'no_send_onlineszamla_by_user': 'bool',
        'order_number': 'str',
        'place_id': 'int',
        'instant_payment': 'bool',
        'selected_type': 'DocumentType'
    }

    attribute_map = {
        'mediated_service': 'mediated_service',
        'without_financial_fulfillment': 'without_financial_fulfillment',
        'online_payment': 'online_payment',
        'round': 'round',
        'no_send_onlineszamla_by_user': 'no_send_onlineszamla_by_user',
        'order_number': 'order_number',
        'place_id': 'place_id',
        'instant_payment': 'instant_payment',
        'selected_type': 'selected_type'
    }

    def __init__(self, mediated_service=False, without_financial_fulfillment=False, online_payment=None, round=None, no_send_onlineszamla_by_user=None, order_number=None, place_id=None, instant_payment=None, selected_type=None):  # noqa: E501
        """DocumentSettings - a model defined in Swagger"""  # noqa: E501
        self._mediated_service = None
        self._without_financial_fulfillment = None
        self._online_payment = None
        self._round = None
        self._no_send_onlineszamla_by_user = None
        self._order_number = None
        self._place_id = None
        self._instant_payment = None
        self._selected_type = None
        self.discriminator = None
        if mediated_service is not None:
            self.mediated_service = mediated_service
        if without_financial_fulfillment is not None:
            self.without_financial_fulfillment = without_financial_fulfillment
        if online_payment is not None:
            self.online_payment = online_payment
        if round is not None:
            self.round = round
        if no_send_onlineszamla_by_user is not None:
            self.no_send_onlineszamla_by_user = no_send_onlineszamla_by_user
        if order_number is not None:
            self.order_number = order_number
        if place_id is not None:
            self.place_id = place_id
        if instant_payment is not None:
            self.instant_payment = instant_payment
        if selected_type is not None:
            self.selected_type = selected_type

    @property
    def mediated_service(self):
        """Gets the mediated_service of this DocumentSettings.  # noqa: E501


        :return: The mediated_service of this DocumentSettings.  # noqa: E501
        :rtype: bool
        """
        return self._mediated_service

    @mediated_service.setter
    def mediated_service(self, mediated_service):
        """Sets the mediated_service of this DocumentSettings.


        :param mediated_service: The mediated_service of this DocumentSettings.  # noqa: E501
        :type: bool
        """

        self._mediated_service = mediated_service

    @property
    def without_financial_fulfillment(self):
        """Gets the without_financial_fulfillment of this DocumentSettings.  # noqa: E501


        :return: The without_financial_fulfillment of this DocumentSettings.  # noqa: E501
        :rtype: bool
        """
        return self._without_financial_fulfillment

    @without_financial_fulfillment.setter
    def without_financial_fulfillment(self, without_financial_fulfillment):
        """Sets the without_financial_fulfillment of this DocumentSettings.


        :param without_financial_fulfillment: The without_financial_fulfillment of this DocumentSettings.  # noqa: E501
        :type: bool
        """

        self._without_financial_fulfillment = without_financial_fulfillment

    @property
    def online_payment(self):
        """Gets the online_payment of this DocumentSettings.  # noqa: E501


        :return: The online_payment of this DocumentSettings.  # noqa: E501
        :rtype: OnlinePayment
        """
        return self._online_payment

    @online_payment.setter
    def online_payment(self, online_payment):
        """Sets the online_payment of this DocumentSettings.


        :param online_payment: The online_payment of this DocumentSettings.  # noqa: E501
        :type: OnlinePayment
        """

        self._online_payment = online_payment

    @property
    def round(self):
        """Gets the round of this DocumentSettings.  # noqa: E501


        :return: The round of this DocumentSettings.  # noqa: E501
        :rtype: Round
        """
        return self._round

    @round.setter
    def round(self, round):
        """Sets the round of this DocumentSettings.


        :param round: The round of this DocumentSettings.  # noqa: E501
        :type: Round
        """

        self._round = round

    @property
    def no_send_onlineszamla_by_user(self):
        """Gets the no_send_onlineszamla_by_user of this DocumentSettings.  # noqa: E501


        :return: The no_send_onlineszamla_by_user of this DocumentSettings.  # noqa: E501
        :rtype: bool
        """
        return self._no_send_onlineszamla_by_user

    @no_send_onlineszamla_by_user.setter
    def no_send_onlineszamla_by_user(self, no_send_onlineszamla_by_user):
        """Sets the no_send_onlineszamla_by_user of this DocumentSettings.


        :param no_send_onlineszamla_by_user: The no_send_onlineszamla_by_user of this DocumentSettings.  # noqa: E501
        :type: bool
        """

        self._no_send_onlineszamla_by_user = no_send_onlineszamla_by_user

    @property
    def order_number(self):
        """Gets the order_number of this DocumentSettings.  # noqa: E501


        :return: The order_number of this DocumentSettings.  # noqa: E501
        :rtype: str
        """
        return self._order_number

    @order_number.setter
    def order_number(self, order_number):
        """Sets the order_number of this DocumentSettings.


        :param order_number: The order_number of this DocumentSettings.  # noqa: E501
        :type: str
        """

        self._order_number = order_number

    @property
    def place_id(self):
        """Gets the place_id of this DocumentSettings.  # noqa: E501


        :return: The place_id of this DocumentSettings.  # noqa: E501
        :rtype: int
        """
        return self._place_id

    @place_id.setter
    def place_id(self, place_id):
        """Sets the place_id of this DocumentSettings.


        :param place_id: The place_id of this DocumentSettings.  # noqa: E501
        :type: int
        """

        self._place_id = place_id

    @property
    def instant_payment(self):
        """Gets the instant_payment of this DocumentSettings.  # noqa: E501


        :return: The instant_payment of this DocumentSettings.  # noqa: E501
        :rtype: bool
        """
        return self._instant_payment

    @instant_payment.setter
    def instant_payment(self, instant_payment):
        """Sets the instant_payment of this DocumentSettings.


        :param instant_payment: The instant_payment of this DocumentSettings.  # noqa: E501
        :type: bool
        """

        self._instant_payment = instant_payment

    @property
    def selected_type(self):
        """Gets the selected_type of this DocumentSettings.  # noqa: E501


        :return: The selected_type of this DocumentSettings.  # noqa: E501
        :rtype: DocumentType
        """
        return self._selected_type

    @selected_type.setter
    def selected_type(self, selected_type):
        """Sets the selected_type of this DocumentSettings.


        :param selected_type: The selected_type of this DocumentSettings.  # noqa: E501
        :type: DocumentType
        """

        self._selected_type = selected_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentSettings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SpendingListItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'organization_id': 'int',
        'category': 'Category',
        'paid_at': 'date',
        'fulfillment_date': 'date',
        'partner': 'SpendingPartner',
        'invoice_number': 'str',
        'currency': 'Currency',
        'conversion_rate': 'float',
        'total_gross': 'float',
        'total_gross_local': 'float',
        'total_vat_amount': 'float',
        'total_vat_amount_local': 'float',
        'invoice_date': 'date',
        'due_date': 'date',
        'payment_method': 'SpendingPaymentMethod',
        'comment': 'str',
        'is_created_by_nav': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'organization_id': 'organization_id',
        'category': 'category',
        'paid_at': 'paid_at',
        'fulfillment_date': 'fulfillment_date',
        'partner': 'partner',
        'invoice_number': 'invoice_number',
        'currency': 'currency',
        'conversion_rate': 'conversion_rate',
        'total_gross': 'total_gross',
        'total_gross_local': 'total_gross_local',
        'total_vat_amount': 'total_vat_amount',
        'total_vat_amount_local': 'total_vat_amount_local',
        'invoice_date': 'invoice_date',
        'due_date': 'due_date',
        'payment_method': 'payment_method',
        'comment': 'comment',
        'is_created_by_nav': 'is_created_by_nav'
    }

    def __init__(self, id=None, organization_id=None, category=None, paid_at=None, fulfillment_date=None, partner=None, invoice_number=None, currency=None, conversion_rate=None, total_gross=None, total_gross_local=None, total_vat_amount=None, total_vat_amount_local=None, invoice_date=None, due_date=None, payment_method=None, comment=None, is_created_by_nav=None):  # noqa: E501
        """SpendingListItem - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._organization_id = None
        self._category = None
        self._paid_at = None
        self._fulfillment_date = None
        self._partner = None
        self._invoice_number = None
        self._currency = None
        self._conversion_rate = None
        self._total_gross = None
        self._total_gross_local = None
        self._total_vat_amount = None
        self._total_vat_amount_local = None
        self._invoice_date = None
        self._due_date = None
        self._payment_method = None
        self._comment = None
        self._is_created_by_nav = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if organization_id is not None:
            self.organization_id = organization_id
        if category is not None:
            self.category = category
        if paid_at is not None:
            self.paid_at = paid_at
        if fulfillment_date is not None:
            self.fulfillment_date = fulfillment_date
        if partner is not None:
            self.partner = partner
        if invoice_number is not None:
            self.invoice_number = invoice_number
        if currency is not None:
            self.currency = currency
        if conversion_rate is not None:
            self.conversion_rate = conversion_rate
        if total_gross is not None:
            self.total_gross = total_gross
        if total_gross_local is not None:
            self.total_gross_local = total_gross_local
        if total_vat_amount is not None:
            self.total_vat_amount = total_vat_amount
        if total_vat_amount_local is not None:
            self.total_vat_amount_local = total_vat_amount_local
        if invoice_date is not None:
            self.invoice_date = invoice_date
        if due_date is not None:
            self.due_date = due_date
        if payment_method is not None:
            self.payment_method = payment_method
        if comment is not None:
            self.comment = comment
        if is_created_by_nav is not None:
            self.is_created_by_nav = is_created_by_nav

    @property
    def id(self):
        """Gets the id of this SpendingListItem.  # noqa: E501


        :return: The id of this SpendingListItem.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SpendingListItem.


        :param id: The id of this SpendingListItem.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def organization_id(self):
        """Gets the organization_id of this SpendingListItem.  # noqa: E501


        :return: The organization_id of this SpendingListItem.  # noqa: E501
        :rtype: int
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """Sets the organization_id of this SpendingListItem.


        :param organization_id: The organization_id of this SpendingListItem.  # noqa: E501
        :type: int
        """

        self._organization_id = organization_id

    @property
    def category(self):
        """Gets the category of this SpendingListItem.  # noqa: E501


        :return: The category of this SpendingListItem.  # noqa: E501
        :rtype: Category
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this SpendingListItem.


        :param category: The category of this SpendingListItem.  # noqa: E501
        :type: Category
        """

        self._category = category

    @property
    def paid_at(self):
        """Gets the paid_at of this SpendingListItem.  # noqa: E501


        :return: The paid_at of this SpendingListItem.  # noqa: E501
        :rtype: date
        """
        return self._paid_at

    @paid_at.setter
    def paid_at(self, paid_at):
        """Sets the paid_at of this SpendingListItem.


        :param paid_at: The paid_at of this SpendingListItem.  # noqa: E501
        :type: date
        """

        self._paid_at = paid_at

    @property
    def fulfillment_date(self):
        """Gets the fulfillment_date of this SpendingListItem.  # noqa: E501


        :return: The fulfillment_date of this SpendingListItem.  # noqa: E501
        :rtype: date
        """
        return self._fulfillment_date

    @fulfillment_date.setter
    def fulfillment_date(self, fulfillment_date):
        """Sets the fulfillment_date of this SpendingListItem.


        :param fulfillment_date: The fulfillment_date of this SpendingListItem.  # noqa: E501
        :type: date
        """

        self._fulfillment_date = fulfillment_date

    @property
    def partner(self):
        """Gets the partner of this SpendingListItem.  # noqa: E501


        :return: The partner of this SpendingListItem.  # noqa: E501
        :rtype: SpendingPartner
        """
        return self._partner

    @partner.setter
    def partner(self, partner):
        """Sets the partner of this SpendingListItem.


        :param partner: The partner of this SpendingListItem.  # noqa: E501
        :type: SpendingPartner
        """

        self._partner = partner

    @property
    def invoice_number(self):
        """Gets the invoice_number of this SpendingListItem.  # noqa: E501


        :return: The invoice_number of this SpendingListItem.  # noqa: E501
        :rtype: str
        """
        return self._invoice_number

    @invoice_number.setter
    def invoice_number(self, invoice_number):
        """Sets the invoice_number of this SpendingListItem.


        :param invoice_number: The invoice_number of this SpendingListItem.  # noqa: E501
        :type: str
        """

        self._invoice_number = invoice_number

    @property
    def currency(self):
        """Gets the currency of this SpendingListItem.  # noqa: E501


        :return: The currency of this SpendingListItem.  # noqa: E501
        :rtype: Currency
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this SpendingListItem.


        :param currency: The currency of this SpendingListItem.  # noqa: E501
        :type: Currency
        """

        self._currency = currency

    @property
    def conversion_rate(self):
        """Gets the conversion_rate of this SpendingListItem.  # noqa: E501


        :return: The conversion_rate of this SpendingListItem.  # noqa: E501
        :rtype: float
        """
        return self._conversion_rate

    @conversion_rate.setter
    def conversion_rate(self, conversion_rate):
        """Sets the conversion_rate of this SpendingListItem.


        :param conversion_rate: The conversion_rate of this SpendingListItem.  # noqa: E501
        :type: float
        """

        self._conversion_rate = conversion_rate

    @property
    def total_gross(self):
        """Gets the total_gross of this SpendingListItem.  # noqa: E501


        :return: The total_gross of this SpendingListItem.  # noqa: E501
        :rtype: float
        """
        return self._total_gross

    @total_gross.setter
    def total_gross(self, total_gross):
        """Sets the total_gross of this SpendingListItem.


        :param total_gross: The total_gross of this SpendingListItem.  # noqa: E501
        :type: float
        """

        self._total_gross = total_gross

    @property
    def total_gross_local(self):
        """Gets the total_gross_local of this SpendingListItem.  # noqa: E501


        :return: The total_gross_local of this SpendingListItem.  # noqa: E501
        :rtype: float
        """
        return self._total_gross_local

    @total_gross_local.setter
    def total_gross_local(self, total_gross_local):
        """Sets the total_gross_local of this SpendingListItem.


        :param total_gross_local: The total_gross_local of this SpendingListItem.  # noqa: E501
        :type: float
        """

        self._total_gross_local = total_gross_local

    @property
    def total_vat_amount(self):
        """Gets the total_vat_amount of this SpendingListItem.  # noqa: E501


        :return: The total_vat_amount of this SpendingListItem.  # noqa: E501
        :rtype: float
        """
        return self._total_vat_amount

    @total_vat_amount.setter
    def total_vat_amount(self, total_vat_amount):
        """Sets the total_vat_amount of this SpendingListItem.


        :param total_vat_amount: The total_vat_amount of this SpendingListItem.  # noqa: E501
        :type: float
        """

        self._total_vat_amount = total_vat_amount

    @property
    def total_vat_amount_local(self):
        """Gets the total_vat_amount_local of this SpendingListItem.  # noqa: E501


        :return: The total_vat_amount_local of this SpendingListItem.  # noqa: E501
        :rtype: float
        """
        return self._total_vat_amount_local

    @total_vat_amount_local.setter
    def total_vat_amount_local(self, total_vat_amount_local):
        """Sets the total_vat_amount_local of this SpendingListItem.


        :param total_vat_amount_local: The total_vat_amount_local of this SpendingListItem.  # noqa: E501
        :type: float
        """

        self._total_vat_amount_local = total_vat_amount_local

    @property
    def invoice_date(self):
        """Gets the invoice_date of this SpendingListItem.  # noqa: E501


        :return: The invoice_date of this SpendingListItem.  # noqa: E501
        :rtype: date
        """
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, invoice_date):
        """Sets the invoice_date of this SpendingListItem.


        :param invoice_date: The invoice_date of this SpendingListItem.  # noqa: E501
        :type: date
        """

        self._invoice_date = invoice_date

    @property
    def due_date(self):
        """Gets the due_date of this SpendingListItem.  # noqa: E501


        :return: The due_date of this SpendingListItem.  # noqa: E501
        :rtype: date
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this SpendingListItem.


        :param due_date: The due_date of this SpendingListItem.  # noqa: E501
        :type: date
        """

        self._due_date = due_date

    @property
    def payment_method(self):
        """Gets the payment_method of this SpendingListItem.  # noqa: E501


        :return: The payment_method of this SpendingListItem.  # noqa: E501
        :rtype: SpendingPaymentMethod
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this SpendingListItem.


        :param payment_method: The payment_method of this SpendingListItem.  # noqa: E501
        :type: SpendingPaymentMethod
        """

        self._payment_method = payment_method

    @property
    def comment(self):
        """Gets the comment of this SpendingListItem.  # noqa: E501


        :return: The comment of this SpendingListItem.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this SpendingListItem.


        :param comment: The comment of this SpendingListItem.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def is_created_by_nav(self):
        """Gets the is_created_by_nav of this SpendingListItem.  # noqa: E501


        :return: The is_created_by_nav of this SpendingListItem.  # noqa: E501
        :rtype: bool
        """
        return self._is_created_by_nav

    @is_created_by_nav.setter
    def is_created_by_nav(self, is_created_by_nav):
        """Sets the is_created_by_nav of this SpendingListItem.


        :param is_created_by_nav: The is_created_by_nav of this SpendingListItem.  # noqa: E501
        :type: bool
        """

        self._is_created_by_nav = is_created_by_nav

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SpendingListItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpendingListItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DocumentInsert(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'vendor_id': 'str',
        'partner_id': 'int',
        'block_id': 'int',
        'bank_account_id': 'int',
        'type': 'DocumentInsertType',
        'fulfillment_date': 'date',
        'due_date': 'date',
        'payment_method': 'PaymentMethod',
        'language': 'DocumentLanguage',
        'currency': 'Currency',
        'conversion_rate': 'float',
        'electronic': 'bool',
        'paid': 'bool',
        'items': 'list[OneOfDocumentInsertItemsItems]',
        'comment': 'str',
        'settings': 'DocumentSettings',
        'advance_invoice': 'list[int]',
        'discount': 'Discount',
        'instant_payment': 'bool'
    }

    attribute_map = {
        'vendor_id': 'vendor_id',
        'partner_id': 'partner_id',
        'block_id': 'block_id',
        'bank_account_id': 'bank_account_id',
        'type': 'type',
        'fulfillment_date': 'fulfillment_date',
        'due_date': 'due_date',
        'payment_method': 'payment_method',
        'language': 'language',
        'currency': 'currency',
        'conversion_rate': 'conversion_rate',
        'electronic': 'electronic',
        'paid': 'paid',
        'items': 'items',
        'comment': 'comment',
        'settings': 'settings',
        'advance_invoice': 'advance_invoice',
        'discount': 'discount',
        'instant_payment': 'instant_payment'
    }

    def __init__(self, vendor_id=None, partner_id=None, block_id=None, bank_account_id=None, type=None, fulfillment_date=None, due_date=None, payment_method=None, language=None, currency=None, conversion_rate=None, electronic=False, paid=False, items=None, comment=None, settings=None, advance_invoice=None, discount=None, instant_payment=None):  # noqa: E501
        """DocumentInsert - a model defined in Swagger"""  # noqa: E501
        self._vendor_id = None
        self._partner_id = None
        self._block_id = None
        self._bank_account_id = None
        self._type = None
        self._fulfillment_date = None
        self._due_date = None
        self._payment_method = None
        self._language = None
        self._currency = None
        self._conversion_rate = None
        self._electronic = None
        self._paid = None
        self._items = None
        self._comment = None
        self._settings = None
        self._advance_invoice = None
        self._discount = None
        self._instant_payment = None
        self.discriminator = None
        if vendor_id is not None:
            self.vendor_id = vendor_id
        self.partner_id = partner_id
        self.block_id = block_id
        if bank_account_id is not None:
            self.bank_account_id = bank_account_id
        self.type = type
        self.fulfillment_date = fulfillment_date
        self.due_date = due_date
        self.payment_method = payment_method
        self.language = language
        self.currency = currency
        if conversion_rate is not None:
            self.conversion_rate = conversion_rate
        if electronic is not None:
            self.electronic = electronic
        if paid is not None:
            self.paid = paid
        if items is not None:
            self.items = items
        if comment is not None:
            self.comment = comment
        if settings is not None:
            self.settings = settings
        if advance_invoice is not None:
            self.advance_invoice = advance_invoice
        if discount is not None:
            self.discount = discount
        if instant_payment is not None:
            self.instant_payment = instant_payment

    @property
    def vendor_id(self):
        """Gets the vendor_id of this DocumentInsert.  # noqa: E501


        :return: The vendor_id of this DocumentInsert.  # noqa: E501
        :rtype: str
        """
        return self._vendor_id

    @vendor_id.setter
    def vendor_id(self, vendor_id):
        """Sets the vendor_id of this DocumentInsert.


        :param vendor_id: The vendor_id of this DocumentInsert.  # noqa: E501
        :type: str
        """

        self._vendor_id = vendor_id

    @property
    def partner_id(self):
        """Gets the partner_id of this DocumentInsert.  # noqa: E501


        :return: The partner_id of this DocumentInsert.  # noqa: E501
        :rtype: int
        """
        return self._partner_id

    @partner_id.setter
    def partner_id(self, partner_id):
        """Sets the partner_id of this DocumentInsert.


        :param partner_id: The partner_id of this DocumentInsert.  # noqa: E501
        :type: int
        """
        if partner_id is None:
            raise ValueError("Invalid value for `partner_id`, must not be `None`")  # noqa: E501

        self._partner_id = partner_id

    @property
    def block_id(self):
        """Gets the block_id of this DocumentInsert.  # noqa: E501


        :return: The block_id of this DocumentInsert.  # noqa: E501
        :rtype: int
        """
        return self._block_id

    @block_id.setter
    def block_id(self, block_id):
        """Sets the block_id of this DocumentInsert.


        :param block_id: The block_id of this DocumentInsert.  # noqa: E501
        :type: int
        """
        if block_id is None:
            raise ValueError("Invalid value for `block_id`, must not be `None`")  # noqa: E501

        self._block_id = block_id

    @property
    def bank_account_id(self):
        """Gets the bank_account_id of this DocumentInsert.  # noqa: E501


        :return: The bank_account_id of this DocumentInsert.  # noqa: E501
        :rtype: int
        """
        return self._bank_account_id

    @bank_account_id.setter
    def bank_account_id(self, bank_account_id):
        """Sets the bank_account_id of this DocumentInsert.


        :param bank_account_id: The bank_account_id of this DocumentInsert.  # noqa: E501
        :type: int
        """

        self._bank_account_id = bank_account_id

    @property
    def type(self):
        """Gets the type of this DocumentInsert.  # noqa: E501


        :return: The type of this DocumentInsert.  # noqa: E501
        :rtype: DocumentInsertType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DocumentInsert.


        :param type: The type of this DocumentInsert.  # noqa: E501
        :type: DocumentInsertType
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def fulfillment_date(self):
        """Gets the fulfillment_date of this DocumentInsert.  # noqa: E501


        :return: The fulfillment_date of this DocumentInsert.  # noqa: E501
        :rtype: date
        """
        return self._fulfillment_date

    @fulfillment_date.setter
    def fulfillment_date(self, fulfillment_date):
        """Sets the fulfillment_date of this DocumentInsert.


        :param fulfillment_date: The fulfillment_date of this DocumentInsert.  # noqa: E501
        :type: date
        """
        if fulfillment_date is None:
            raise ValueError("Invalid value for `fulfillment_date`, must not be `None`")  # noqa: E501

        self._fulfillment_date = fulfillment_date

    @property
    def due_date(self):
        """Gets the due_date of this DocumentInsert.  # noqa: E501


        :return: The due_date of this DocumentInsert.  # noqa: E501
        :rtype: date
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this DocumentInsert.


        :param due_date: The due_date of this DocumentInsert.  # noqa: E501
        :type: date
        """
        if due_date is None:
            raise ValueError("Invalid value for `due_date`, must not be `None`")  # noqa: E501

        self._due_date = due_date

    @property
    def payment_method(self):
        """Gets the payment_method of this DocumentInsert.  # noqa: E501


        :return: The payment_method of this DocumentInsert.  # noqa: E501
        :rtype: PaymentMethod
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this DocumentInsert.


        :param payment_method: The payment_method of this DocumentInsert.  # noqa: E501
        :type: PaymentMethod
        """
        if payment_method is None:
            raise ValueError("Invalid value for `payment_method`, must not be `None`")  # noqa: E501

        self._payment_method = payment_method

    @property
    def language(self):
        """Gets the language of this DocumentInsert.  # noqa: E501


        :return: The language of this DocumentInsert.  # noqa: E501
        :rtype: DocumentLanguage
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this DocumentInsert.


        :param language: The language of this DocumentInsert.  # noqa: E501
        :type: DocumentLanguage
        """
        if language is None:
            raise ValueError("Invalid value for `language`, must not be `None`")  # noqa: E501

        self._language = language

    @property
    def currency(self):
        """Gets the currency of this DocumentInsert.  # noqa: E501


        :return: The currency of this DocumentInsert.  # noqa: E501
        :rtype: Currency
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this DocumentInsert.


        :param currency: The currency of this DocumentInsert.  # noqa: E501
        :type: Currency
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501

        self._currency = currency

    @property
    def conversion_rate(self):
        """Gets the conversion_rate of this DocumentInsert.  # noqa: E501


        :return: The conversion_rate of this DocumentInsert.  # noqa: E501
        :rtype: float
        """
        return self._conversion_rate

    @conversion_rate.setter
    def conversion_rate(self, conversion_rate):
        """Sets the conversion_rate of this DocumentInsert.


        :param conversion_rate: The conversion_rate of this DocumentInsert.  # noqa: E501
        :type: float
        """

        self._conversion_rate = conversion_rate

    @property
    def electronic(self):
        """Gets the electronic of this DocumentInsert.  # noqa: E501


        :return: The electronic of this DocumentInsert.  # noqa: E501
        :rtype: bool
        """
        return self._electronic

    @electronic.setter
    def electronic(self, electronic):
        """Sets the electronic of this DocumentInsert.


        :param electronic: The electronic of this DocumentInsert.  # noqa: E501
        :type: bool
        """

        self._electronic = electronic

    @property
    def paid(self):
        """Gets the paid of this DocumentInsert.  # noqa: E501


        :return: The paid of this DocumentInsert.  # noqa: E501
        :rtype: bool
        """
        return self._paid

    @paid.setter
    def paid(self, paid):
        """Sets the paid of this DocumentInsert.


        :param paid: The paid of this DocumentInsert.  # noqa: E501
        :type: bool
        """

        self._paid = paid

    @property
    def items(self):
        """Gets the items of this DocumentInsert.  # noqa: E501


        :return: The items of this DocumentInsert.  # noqa: E501
        :rtype: list[OneOfDocumentInsertItemsItems]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this DocumentInsert.


        :param items: The items of this DocumentInsert.  # noqa: E501
        :type: list[OneOfDocumentInsertItemsItems]
        """

        self._items = items

    @property
    def comment(self):
        """Gets the comment of this DocumentInsert.  # noqa: E501


        :return: The comment of this DocumentInsert.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this DocumentInsert.


        :param comment: The comment of this DocumentInsert.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def settings(self):
        """Gets the settings of this DocumentInsert.  # noqa: E501


        :return: The settings of this DocumentInsert.  # noqa: E501
        :rtype: DocumentSettings
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this DocumentInsert.


        :param settings: The settings of this DocumentInsert.  # noqa: E501
        :type: DocumentSettings
        """

        self._settings = settings

    @property
    def advance_invoice(self):
        """Gets the advance_invoice of this DocumentInsert.  # noqa: E501


        :return: The advance_invoice of this DocumentInsert.  # noqa: E501
        :rtype: list[int]
        """
        return self._advance_invoice

    @advance_invoice.setter
    def advance_invoice(self, advance_invoice):
        """Sets the advance_invoice of this DocumentInsert.


        :param advance_invoice: The advance_invoice of this DocumentInsert.  # noqa: E501
        :type: list[int]
        """

        self._advance_invoice = advance_invoice

    @property
    def discount(self):
        """Gets the discount of this DocumentInsert.  # noqa: E501


        :return: The discount of this DocumentInsert.  # noqa: E501
        :rtype: Discount
        """
        return self._discount

    @discount.setter
    def discount(self, discount):
        """Sets the discount of this DocumentInsert.


        :param discount: The discount of this DocumentInsert.  # noqa: E501
        :type: Discount
        """

        self._discount = discount

    @property
    def instant_payment(self):
        """Gets the instant_payment of this DocumentInsert.  # noqa: E501


        :return: The instant_payment of this DocumentInsert.  # noqa: E501
        :rtype: bool
        """
        return self._instant_payment

    @instant_payment.setter
    def instant_payment(self, instant_payment):
        """Sets the instant_payment of this DocumentInsert.


        :param instant_payment: The instant_payment of this DocumentInsert.  # noqa: E501
        :type: bool
        """

        self._instant_payment = instant_payment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentInsert, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentInsert):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "billingo"
VERSION = "0.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Billingo API v3",
    author_email="github@axonltd.hu",
    url="https://www.axonltd.hu/",
    keywords=["Swagger", "Billingo API v3"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501
    """
)
